# Generated by sila2.code_generator; sila2.__version__: 0.12.2
from os.path import dirname, join

from sila2.framework import Feature

SessionManagementFeature = Feature(join(dirname(__file__), "SessionManagement.sila.xml"))
